Package: EviewsR
Type: Package
Title: A Seamless Integration of 'EViews' and R
Version: 0.1.7
Authors@R: c(
    person("Sagiru", "Mati", role = c("aut", "cre"), email = "sagirumati@gmail.com",comment=c(ORCID="0000-0003-1413-3974")))
Maintainer: Sagiru Mati <sagirumati@gmail.com>
Description: It allows running 'EViews' (<https://eviews.com>) program from R, R Markdown and Quarto documents. 'EViews' (Econometric Views) is a statistical software for Econometric analysis.  This package integrates 'EViews' and R and also serves as an 'EViews' Knit-Engine for 'knitr' package. Write all your 'EViews' commands in R, R Markdown or Quarto documents. For details,  please consult our peer-review article Mati S., Civcir I. and Abba S.I (2023) <doi:10.32614/RJ-2023-045>.
Depends: R (>= 3.4.0)
Imports: knitr (>= 1.20), magrittr, xts, zoo, Rdpack
Suggests: rmarkdown, testthat, ggplot2
SystemRequirements: EViews (>= 8)
License: GPL
URL: https://CRAN.R-project.org/package=EviewsR
BugReports: https://github.com/sagirumati/EviewsR/issues
Encoding: UTF-8
VignetteBuilder: knitr
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-26 16:18:14 UTC; User
Repository: CRAN
Date/Publication: 2026-01-26 16:40:14 UTC
Config/testthat/edition: 3
RdMacros: Rdpack
Author: Sagiru Mati [aut, cre] (ORCID: <https://orcid.org/0000-0003-1413-3974>)
Built: R 4.6.0; ; 2026-04-27 16:39:21 UTC; unix
