# Generated by roxygen2: do not edit by hand

export(create_object)
export(eng_eviews)
export(eviews_graph)
export(eviews_import)
export(eviews_pagesave)
export(eviews_wfcreate)
export(eviews_wfsave)
export(exec_commands)
export(export)
export(export_dataframe)
export(import)
export(import_equation)
export(import_graph)
export(import_kable)
export(import_series)
export(import_table)
export(import_workfile)
export(rwalk)
export(set_eviews_path)
import(knitr)
import(magrittr)
importFrom(Rdpack,reprompt)
importFrom(stats,na.omit)
importFrom(utils,getFromNamespace)
importFrom(utils,read.csv)
importFrom(utils,tail)
importFrom(utils,write.csv)
importFrom(xts,is.xts)
importFrom(xts,xts)
importFrom(zoo,coredata)
importFrom(zoo,index)
